netapp_ontap.models.igroup_initiators_proximity_peer_svms API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.igroup_initiators_proximity_peer_svms`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class IgroupInitiatorsProximityPeerSvmsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the IgroupInitiatorsProximityPeerSvms object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the igroup_initiators_proximity_peer_svms.

  `name: str GET POST PATCH`

    The local name of the peer SVM. This name is unique among all local and peer SVMs.

    Example: peer1

  `uuid: str GET POST PATCH`

    The unique identifier of the SVM peer relationship. This is the UUID of the relationship, not the UUID of the peer SVM itself.

    Example: 4204cf77-4c82-9bdb-5644-b5a841c097a9